@@ -19,21 +19,27 @@ def step_execute_small_query(context):
 
 @when("we execute a large query")
 def step_execute_large_query(context):
-    context.cli.sendline("select {}".format(",".join([str(n) for n in range(1, 50)])))
+    context.cli.sendline(f"select {','.join([str(n) for n in range(1, 50)])}")
 
 
 @then("we see small results in horizontal format")
 def step_see_small_results(context):
+    expected = (
+        dedent(
+            """
+            +---+\r
+            | 1 |\r
+            +---+\r
+            | 1 |\r
+            +---+
+            """
+        ).strip()
+        + '\r\n\r\n'
+    )
+
     wrappers.expect_pager(
         context,
-        dedent("""\
-        +---+\r
-        | 1 |\r
-        +---+\r
-        | 1 |\r
-        +---+\r
-        \r
-        """),
+        expected,
         timeout=5,
     )
     wrappers.expect_exact(context, "1 row in set", timeout=2)
@@ -41,8 +47,9 @@ def step_see_small_results(context):
 
 @then("we see large results in vertical format")
 def step_see_large_results(context):
-    rows = ["{n:3}| {n}".format(n=str(n)) for n in range(1, 50)]
-    expected = "***************************[ 1. row ]***************************\r\n" + "{}\r\n".format("\r\n".join(rows) + "\r\n")
+    rows = [f"{str(n):3}| {n}" for n in range(1, 50)]
+    delimited_rows = '\r\n'.join(rows) + '\r\n'
+    expected = "***************************[ 1. row ]***************************\r\n" + delimited_rows + "\r\n"
 
     wrappers.expect_pager(context, expected, timeout=10)
     wrappers.expect_exact(context, "1 row in set", timeout=2)
